==> vue3-components-0.2.28.tgz: package/es/selectArea/src/selectArea.vue.js <==
import { defineComponent as D, ref as v, computed as y, watch as i, resolveComponent as f, openBlock as c, createBlock as d, normalizeClass as U, unref as s, withCtx as m, createVNode as b, mergeProps as _, createElementBlock as V, Fragment as A, renderList as g } from "vue";
import { selectAreaProps as N } from "./selectArea.js";
import { createNamespacs as P } from "@tomiaa/utils";
import C from "./lib/pac-code.json.js";
const z = {
  name: "KSelectArea"
}, j = /* @__PURE__ */ D({
  ...z,
  props: N,
  emits: ["change"],
  setup(E, { emit: k }) {
    const w = P("progress"), t = v(), n = v(), r = v(), p = y(
      () => {
        var a;
        return ((a = C.find((l) => l.code === t.value)) == null ? void 0 : a.children) || [];
      }
    ), h = y(
      () => {
        var a, l;
        return ((l = (a = p.value) == null ? void 0 : a.find((u) => u.code === n.value)) == null ? void 0 : l.children) || [];
      }
    );
    return i(t, () => {
      n.value = "";
    }), i(n, () => {
      r.value = "";
    }), i(r, () => {
      if (!r.value)
        return;
      const a = {
        code: t.value,
        name: C.find((o) => o.code === t.value).name
      }, l = {
        code: n.value,
        name: p.value.find(
          (o) => o.code === n.value
        ).name
      }, u = {
        code: r.value,
        name: h.value.find(
          (o) => o.code === r.value
        ).name
      };
      k("change", { provinceData: a, cityData: l, areaData: u });
    }), (a, l) => {
      const u = f("el-option"), o = f("el-select"), B = f("el-space");
      return c(), d(B, {
        wrap: "",
        class: U(s(w).b())
      }, {
        default: m(() => [
          b(o, _({
            modelValue: t.value,
            "onUpdate:modelValue": l[0] || (l[0] = (e) => t.value = e),
            placeholder: "请选择省份",
            clearable: "",
            filterable: ""
          }, a.provinceAttrs), {
            default: m(() => [
              (c(!0), V(A, null, g(s(C), (e) => (c(), d(u, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue"]),
          b(o, _({
            modelValue: n.value,
            "onUpdate:modelValue": l[1] || (l[1] = (e) => n.value = e),
            placeholder: "请选择城市",
            clearable: "",
            filterable: "",
            disabled: !t.value
          }, a.cityAttrs), {
            default: m(() => [
              (c(!0), V(A, null, g(s(p), (e) => (c(), d(u, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"]),
          b(o, _({
            modelValue: r.value,
            "onUpdate:modelValue": l[2] || (l[2] = (e) => r.value = e),
            placeholder: "请选择区域",
            clearable: "",
            filterable: "",
            disabled: !t.value || !n.value
          }, a.areaAttrs), {
            default: m(() => [
              (c(!0), V(A, null, g(s(h), (e) => (c(), d(u, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"])
        ]),
        _: 1
      }, 8, ["class"]);
    };
  }
});
export {
  j as default
};

==> vue3-components-0.2.32.tgz: package/es/selectArea/src/selectArea.vue.js <==
import { defineComponent as k, ref as v, computed as y, watch as i, resolveComponent as f, openBlock as c, createBlock as d, normalizeClass as U, unref as s, withCtx as m, createVNode as b, mergeProps as _, createElementBlock as V, Fragment as A, renderList as g } from "vue";
import { selectAreaProps as N } from "./selectArea.js";
import { createNamespacs as P } from "@tomiaa/utils";
import C from "./lib/pac-code.json.js";
const z = k({
  name: "KSelectArea"
}), j = /* @__PURE__ */ k({
  ...z,
  props: N,
  emits: ["change"],
  setup(E, { emit: w }) {
    const B = P("progress"), t = v(), n = v(), r = v(), p = y(
      () => {
        var a;
        return ((a = C.find((l) => l.code === t.value)) == null ? void 0 : a.children) || [];
      }
    ), h = y(
      () => {
        var a, l;
        return ((l = (a = p.value) == null ? void 0 : a.find((u) => u.code === n.value)) == null ? void 0 : l.children) || [];
      }
    );
    return i(t, () => {
      n.value = "";
    }), i(n, () => {
      r.value = "";
    }), i(r, () => {
      if (!r.value)
        return;
      const a = {
        code: t.value,
        name: C.find((o) => o.code === t.value).name
      }, l = {
        code: n.value,
        name: p.value.find(
          (o) => o.code === n.value
        ).name
      }, u = {
        code: r.value,
        name: h.value.find(
          (o) => o.code === r.value
        ).name
      };
      w("change", { provinceData: a, cityData: l, areaData: u });
    }), (a, l) => {
      const u = f("el-option"), o = f("el-select"), D = f("el-space");
      return c(), d(D, {
        wrap: "",
        class: U(s(B).b())
      }, {
        default: m(() => [
          b(o, _({
            modelValue: t.value,
            "onUpdate:modelValue": l[0] || (l[0] = (e) => t.value = e),
            placeholder: "请选择省份",
            clearable: "",
            filterable: ""
          }, a.provinceAttrs), {
            default: m(() => [
              (c(!0), V(A, null, g(s(C), (e) => (c(), d(u, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue"]),
          b(o, _({
            modelValue: n.value,
            "onUpdate:modelValue": l[1] || (l[1] = (e) => n.value = e),
            placeholder: "请选择城市",
            clearable: "",
            filterable: "",
            disabled: !t.value
          }, a.cityAttrs), {
            default: m(() => [
              (c(!0), V(A, null, g(s(p), (e) => (c(), d(u, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"]),
          b(o, _({
            modelValue: r.value,
            "onUpdate:modelValue": l[2] || (l[2] = (e) => r.value = e),
            placeholder: "请选择区域",
            clearable: "",
            filterable: "",
            disabled: !t.value || !n.value
          }, a.areaAttrs), {
            default: m(() => [
              (c(!0), V(A, null, g(s(h), (e) => (c(), d(u, {
                label: e.name,
                value: e.code
              }, null, 8, ["label", "value"]))), 256))
            ]),
            _: 1
          }, 16, ["modelValue", "disabled"])
        ]),
        _: 1
      }, 8, ["class"]);
    };
  }
});
export {
  j as default
};
